# Griffe Sphinx

[![documentation](https://img.shields.io/badge/docs-mkdocs-708FCC.svg?style=flat)](https://mkdocstrings.github.io/griffe-sphinx/)
[![gitpod](https://img.shields.io/badge/gitpod-workspace-708FCC.svg?style=flat)](https://gitpod.io/#https://github.com/mkdocstrings/griffe-sphinx)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://app.gitter.im/#/room/#griffe-sphinx:gitter.im)

Parse Sphinx-comments above attributes as docstrings.

## Installation

This project is available to sponsors only, through my Insiders program.
See Insiders [explanation](https://mkdocstrings.github.io/griffe-sphinx/insiders/)
and [installation instructions](https://mkdocstrings.github.io/griffe-sphinx/insiders/installation/).
